@@ -4,7 +4,10 @@ from bs4 import BeautifulSoup
 import requests
 import base64
 from PIL import Image
+from os import mkdir
 import io
+from json import loads, dumps
+
 
 # File definitions
 
@@ -20,7 +23,7 @@ root.render(<App />);
 SERVER_TS = """"""
 
 APP_TSX = """import React from 'react';
-import {} from 'server.ts'
+import {} from './server'
 
 export function App() {
     return <h1>Hello from PyReact 👋</h1>;
@@ -67,12 +70,13 @@ export default {
 INPUT_CSS = """@import "tailwindcss";"""
 
 MAIN_PY = """from flask import jsonify
-from pyrekit.server import Server, ServerProcess, pack_app
+from pyrekit.server import Server, ServerProcess
+from pyrekit.files import pack_app, project_name
 import webview
 
 # don't rename this class
 class AppServer(Server):
-    def index(self):
+    async def index(self):
         return pack_app(self.DEV)
 
 if __name__ == "__main__":
@@ -83,7 +87,7 @@ if __name__ == "__main__":
     server_proc = ServerProcess(server=app_server)
     server_proc.start()
     
-    webview.create_window("AppServer", f"http://{HOST}:{PORT}/")
+    webview.create_window(project_name(), f"http://{HOST}:{PORT}/")
     webview.start()
 
     server_proc.close()"""
@@ -172,23 +176,89 @@ def create_function(function_info: Dict[str, str]):
         Creates a typescript function in server.ts for each route in the AppServer
     """
 
-    return f"""
-    function {function_info['name']}() {{
-            ret = {{}};
+    route = "/"+function_info['name'].replace("_", "/")
+    method = function_info['method']
 
-            fetch('{function_info.name.replace("_", "/")}')
-            .then(res => res.json())
-            .then(data => ret = data)
-            .catch(err => console.log(err));
-            
-            return ret;
-        }}
+    if method == "get":
+        return f"""
+export function {function_info['name']}() {{
+  // Fetches data from the '{route}' endpoint.
+  return fetch('{route}')
+    .then(res => {{
+      if (!res.ok) {{
+        throw new Error(`HTTP error! Status: ${{res.status}}`);
+      }}
+      return res.json();
+    }})
+    .catch(err => {{
+      console.error("Fetch error:", err);
+      throw err; // Re-throw the error to be handled by the caller
+    }});
+}}
+"""
+
+    elif method in ["post", "put"]:
+        # POST and PUT requests both send data in the request body.
+        method_upper = method.upper()
+        return f"""
+export function {function_info['name']}(data: any) {{
+  // Sends a {method_upper} request to the '{route}' endpoint.
+  return fetch('{route}', {{
+    method: '{method_upper}',
+    headers: {{
+      'Content-Type': 'application/json',
+    }},
+    body: JSON.stringify(data),
+  }})
+    .then(res => {{
+      if (!res.ok) {{
+        throw new Error(`HTTP error! Status: ${{res.status}}`);
+      }}
+      return res.json();
+    }})
+    .catch(err => {{
+      console.error("Fetch error:", err);
+      throw err; // Re-throw the error to be handled by the caller
+    }});
+}}
+"""
+
+    elif method == "delete":
+        return f"""
+export function {function_info['name']}(id: string | number) {{
+  // Sends a DELETE request to the '{route}/{{id}}' endpoint.
+  return fetch(`{route}/${{id}}`, {{
+    method: 'DELETE',
+  }})
+    .then(res => {{
+      if (!res.ok) {{
+        throw new Error(`HTTP error! Status: ${{res.status}}`);
+      }}
+      return res.json();
+    }})
+    .catch(err => {{
+      console.error("Fetch error:", err);
+      throw err; // Re-throw the error to be handled by the caller
+    }});
+}}
+"""
+    
+    # Return an empty string if the method is not supported
+    return ""
+
+
+def pack_server_functions():
     """
+        Pack all the fetcher functions
+    """
+    functions_info = parse("main.py")
+    functions = [create_function(item) for item in functions_info]
+    
+    for f in functions_info:
+        print(f)
 
-def pack_server_functions() -> str:
-    functions = parse("main.py")
-    functions = [create_function(item) for item in functions]
     server_ts = ""
+
     for item in functions:
         server_ts += item
     
@@ -246,7 +316,32 @@ def pack_app(DEV = False) -> str:
 
     return app_string
 
-def create_files(AppName: str = "PyReact"):
+def get_package() -> Dict[str, str]:
+    """
+        Gets package.json or close the entire programn if not found
+    """
+    json_str = read_file("package.json")
+    if len(json_str) != 0:
+        return loads(json_str)
+    else:
+        print("package.json not found, maybe you did not setup the project!")
+        exit(0)
+
+def project_name() -> str:
+    package = get_package()
+    return package['project-name']
+
+def create_base_dirs() -> None:
+    """
+        Check if the base dirs exists if not create them
+    """
+    try:
+        mkdir("src")
+        mkdir("build")
+    except FileExistsError:
+        print("src and build Folders already exists!")
+
+def create_files(AppName: str = "PyReact") -> None:
     """
     Creates base files for the app
     """
@@ -272,6 +367,39 @@ def create_files(AppName: str = "PyReact"):
     with open("main.py", "w") as fd:
         fd.write(MAIN_PY)
 
+    with open("package.json", "w") as fd:
+        fd.write(create_package(AppName))
+
+
+def create_package(AppName: str) -> str:
+    """
+        Creates a base package.json string
+    """
+
+    package = {
+        "project-name": AppName,
+        "compilerOptions": {
+            "target": "ES6",
+            "module": "ESNext",
+            "jsx": "react-jsx",
+            "strict": True,
+            "moduleResolution": "node",
+            "esModuleInterop": True
+        },
+        "include": ["src"],
+        "scripts": {
+            "tailwindcss_dev": "npx @tailwindcss/cli -i ./src/input.css -o ./build/output.css",
+            "tailwindcss": "npx @tailwindcss/cli -i ./src/input.css -o ./build/output.css -m",
+            "esbuild_dev": "npx esbuild src/index.tsx --sourcemap --bundle --outfile=build/bundle.js --loader:.tsx=tsx",
+            "esbuild": "npx esbuild src/index.tsx --minify --bundle --outfile=build/bundle.js --loader:.tsx=tsx",
+            "build": "npm run tailwindcss && npm run esbuild",
+            "run": "npm run tailwindcss_dev && npm run esbuild_dev"
+        }
+    }
+
+    data = dumps(package, indent=4)
+    return data
+
 
 def read_file(path: str) -> str:
     """
@@ -284,3 +412,13 @@ def read_file(path: str) -> str:
     except FileNotFoundError:
         print("File not Found! ", path)
         return ""
+    
+def list_scripts():
+    """
+    Lists the scripts available in package.json
+    """
+    package = get_package()
+    scripts = package["scripts"].keys()
+    print("Found", len(scripts), "scripts:")
+    for s in scripts:
+        print("\b - ", s)
